# -*- coding: utf-8 -*-
# Generated by Django 1.10.8 on 2017-11-28 11:48
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('codenerix_invoicing', '0062_auto_20171128_1104'),
    ]

    operations = [
        migrations.AddField(
            model_name='saleslinebasket',
            name='tax_label',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Tax Name'),
        ),
        migrations.AddField(
            model_name='saleslineinvoice',
            name='tax_label',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Tax Name'),
        ),
        migrations.AddField(
            model_name='saleslineorder',
            name='tax_label',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Tax Name'),
        ),
        migrations.AddField(
            model_name='saleslineticket',
            name='tax_label',
            field=models.CharField(blank=True, max_length=250, null=True, verbose_name='Tax Name'),
        ),
        migrations.AlterField(
            model_name='saleslinebasket',
            name='tax',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Tax (%)'),
        ),
        migrations.AlterField(
            model_name='saleslineinvoice',
            name='tax',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Tax (%)'),
        ),
        migrations.AlterField(
            model_name='saleslineorder',
            name='tax',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Tax (%)'),
        ),
        migrations.AlterField(
            model_name='saleslineticket',
            name='tax',
            field=models.FloatField(blank=True, default=0, null=True, verbose_name='Tax (%)'),
        ),
    ]
